#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_LIBSM
#undef PACKAGE_LOCALE_DIR
#undef PACKAGE_DATA_DIR
#undef PACKAGE_SOURCE_DIR
#undef HAVE_FTPLIB
#undef HAVE_REALLIB
#undef HAVE_SDLLIB
#undef HAVE_LIBDC
#undef HAVE_LIBRAW
#undef HAVE_GDK_PIXBUF
#undef MMX_SUPPORT
#undef SSE_SUPPORT
#undef SSE2_SUPPORT
#undef HAVE_XV
